import click
import json
import os
from pathlib import Path
from wowpy.livestreams import Livestream
from cli.utils import exception_handler, create_creds_file, credentials_file_exist, get_credentials_path

PROFILE_HELP = """
`wowtool` profile, can be set with WOWTOOL_PROFILE env var.
profile settings in ~/.wow/config.json
"""


@click.group(invoke_without_command=True)
def configure():
    """
    Setup credentials file.
    """

    credentials_path = get_credentials_path()
    if credentials_file_exist(credentials_path):
        if click.confirm('Credentials file already exist, override?'):
            create_creds_file(credentials_path)
            click.echo('Credentials file successfully created!')
    else: 
        create_creds_file(credentials_path)
        click.echo('Credentials file successfully created!')



import json
import click
from click_option_group import optgroup, RequiredMutuallyExclusiveOptionGroup
from wowpy.transcoders import Transcoder
from cli.utils import exception_handler, wowza_auth

PROFILE_HELP = """
`wowtool` profile, can be set with WOWTOOL_PROFILE env var.
profile settings in ~/.wow/config.json
"""


@click.group()
def trans():
    """
    Transcoder commands.
    """
    pass


@trans.command(name='query')
@click.option('--id', required=True, help='Transcoder id.')
@exception_handler
def query(id):
    """Get data for a Transcoder"""
    wowza_auth()
    response = Transcoder.get_transcoder(id)
    click.echo(json.dumps(response, indent=4))

@trans.command(name='start')
@optgroup.group('Transcoder identifier', cls=RequiredMutuallyExclusiveOptionGroup,
                help='Identifier for wowza transcoder')
@optgroup.option('--id', help='Live stream id')
@optgroup.option('--name', help='Live stream name')
@exception_handler
def start(id, name):
    """Start a Transcoder"""
    print(id, name)


import functools
import click
import datetime
import json
import os
from pathlib import Path

def exception_handler(func):
    @functools.wraps(func)
    def wrapper(*args, **kwargs):
        try:
            return func(*args, **kwargs)
        except Exception as e:
            message = 'There was an error in the CLI: {}'.format(str(e))
            click.echo(message, err=True)
            exit(1)

    return wrapper

def wowza_auth():
    credentials_path = get_credentials_path()
    if credentials_file_exist(credentials_path):
        set_credentials_envars(credentials_path)
    else:
        create_creds_file(credentials_path)
        set_credentials_envars(credentials_path)

def get_credentials_path():
    home_path = str(Path.home())
    credentials_path = home_path + '/.wow/'
    return credentials_path

def credentials_file_exist(credentials_path):
    credentials_file_path = get_credentials_file_path(credentials_path)
    if os.path.exists(credentials_file_path):
        return True
    else:
        return False

def get_credentials_file_path(credentials_path):
    credentials_file_path = credentials_path + 'config.json'
    return credentials_file_path

def set_credentials_envars(credentials_path):
    credentials_file_path = get_credentials_file_path(credentials_path)
    with open(credentials_file_path) as json_file:
        credentials_data = json.load(json_file)
        os.environ["WSC_ACCESS_KEY"] = credentials_data['WSC_ACCESS_KEY']
        os.environ["WSC_API_KEY"] = credentials_data['WSC_API_KEY']

def create_creds_file(credentials_path):
    wsc_access_key = click.prompt('Please enter wowza access key')
    wsc_api_key = click.prompt('Please enter wowza api key')
    keys = {
            'WSC_ACCESS_KEY': wsc_access_key,
            'WSC_API_KEY': wsc_api_key
            }
    Path(credentials_path).mkdir(parents=True, exist_ok=True)
    credentials_file_path = get_credentials_file_path(credentials_path)
    with open(credentials_file_path, 'w') as json_file:
        json_file.write(json.dumps(keys, indent=4))


import click
from cli.__version__ import VERSION
from cli.commands.livestream import live
from cli.commands.transcoder import trans
from cli.commands.configure import configure


@click.group()
@click.version_option(version=VERSION)
def cli():
    pass

cli.add_command(live)
cli.add_command(configure)
cli.add_command(trans)


import json
import click
from wowpy.livestreams import Livestream
from cli.utils import exception_handler, wowza_auth

PROFILE_HELP = """
`wowtool` profile, can be set with WOWTOOL_PROFILE env var.
profile settings in ~/.wow/config.json
"""


@click.group()
def live():
    """
    Live Stream commands.
    """
    pass


@live.command(name='query')
@click.option('--id', required=True, help='Live Stream id.')
@exception_handler
def query(id):
    """Get data for a Live Stream"""
    wowza_auth()
    response = Livestream.get_livestream(id)
    click.echo(json.dumps(response, indent=4))

@live.command(name='start')
@click.option('--id', required=True, help='Live stream id')
@exception_handler
def start(id):
    """Start a Live Stream"""
    wowza_auth()
    Livestream.start_livestream(id)
    click.echo('Live Stream started')

@live.command(name='stop')
@click.option('--id', required=True, help='Live stream id')
@exception_handler
def stop(id):
    """Stop a Live Stream"""
    wowza_auth()
    Livestream.stop_livestream(id)
    click.echo('Live Stream stopped')

@live.command(name='state')
@click.option('--id', required=True, help='Live stream id')
@exception_handler
def state(id):
    """Get state for a Live Stream"""
    wowza_auth()
    state = Livestream.get_state(id)
    click.echo('Live Stream state is {0}'.format(state))



import setuptools

with open('VERSION', 'r') as fh:
    version = fh.read().strip()

with open('cli/__version__.py', 'w+') as f:
    f.write('VERSION="{}"'.format(version))

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="wowtool",
    version=version,
    install_requires=[
      "setuptools",
      "click",
      "wowpy",
      "click-option-group"
    ],
    entry_points='''
        [console_scripts]
        wowtool=cli.wowtool:cli
    ''',
    author="Daniel Barragan",
    author_email="dbarragan1331@gmail.com",
    description="Wowza python management tool - wowtool",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/d4n13lbc/wowtool",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ]
)